@@ -151,7 +151,19 @@ def register_builtins(aurflux: Aurflux, builtins=True):
         ctx.aurflux.cogs = reloaded_cogs
         return Response()
 
-    @CommandCheck.
+    @CommandCheck.has_permissions(discord.Permissions(manage_guild=True ))
+    @aurflux.commandeer(name="setprefix", parsed=False)
+    async def set_prefix(ctx: MessageContext, prefix: str, *_):
+        """
+        Sets the prefix to [prefix]
+        ..setprefix !!
+        :param ctx:
+        :param prefix:
+        :param _:
+        :return:
+        """
+        async with aurflux.CONFIG.writeable_conf(ctx) as cfg:
+            cfg["prefix"] = prefix
 
     if not builtins:
 
@@ -201,7 +213,7 @@ def register_builtins(aurflux: Aurflux, builtins=True):
                 title="\U00002754 Command Help",
                 description=f"Help for `{configs['prefix']}{help_target}`")
             if public_cmds[help_target].argparser:
-                embed.add_field(name="Usage", value=public_cmds[help_target].long_usage)
+                embed.add_field(name="Usage", value=f"{public_cmds[help_target].short_usage}\n{public_cmds[help_target].long_usage}")
             return Response(embed=embed)
 
 
